from setuptools import setup
import sys
import os
from glob import glob

version = None

if sys.argv[-2] == '--version' and 'sdist' in sys.argv:
    version = sys.argv[-1]
    sys.argv.pop()
    sys.argv.pop()

if 'sdist' in sys.argv and not version:
    raise Exception("Please set a version with --version x.y.z")

if not version:
    if 'sdist' in sys.argv:
        raise Exception("Please set a version with --version x.y.z")
    else:
        path_pkg_info = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'PKG-INFO')
        if os.path.isfile(path_pkg_info):
            with open(path_pkg_info, 'r')as f:
                for l in f.readlines():
                    if 'Version' in l:
                        _, version = l.split(' ')
        else:
            print("WARNING: cannot set version in custom setup.py")

if version:
    version = version.strip()
print("version: %s" % version)

setup(
    name='pymacaron-aws',
    version=version,
    url='https://github.com/pymacaron/pymacaron-aws',
    license='BSD',
    author='Erwan Lemonnier',
    author_email='erwan@lemonnier.se',
    description='Deploy a PyMacaron microservice to Amazon aws/docker',
    install_requires=[
        'awsebcli==3.0.5',
        'awscli',
    ],
    tests_require=[
        'awsebcli==3.12.1',
        'awscli',
        'nose',
        'mock',
        'pep8'
    ],
    test_suite='nose.collector',
    packages=['pymacaron_deploy_configs'],
    package_data={'pymacaron_deploy_configs': ['*.template', '*.config']},
    scripts=glob("bin/*"),
    zip_safe=False,
    platforms='any',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)





import os
import subprocess

# directory names whose children should not be checked
IGNORED_DIRS = (".git")

# file names that should be checked even though they do not end in .py
EXTRA_FILES = ()


def check(files):
    """
    Check all files that files yields for pep8 errors.

    Args:
        file: a generator yielding strings referring to files to check

    Returns:
        False if there are errors, else True
    """

    # E501: Line too long
    # E303: Too many blank lines
    args = ["pep8", "--ignore", "E501,E303,E302"] + list(files)
    p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    (out, err) = p.communicate()
    if len(out) != 0:
        print(out)
    if len(err) != 0:
        print(err)
    return not len(out) and not len(err)


def _find_files_to_test():
    current_dir = os.path.dirname(os.path.realpath(__file__))
    parent = os.path.join(current_dir, "..")
    for r, d, files in os.walk(parent):
        for ignored in IGNORED_DIRS:
            if ignored in d:
                d.remove(ignored)
        for dir_ in d:
            if dir_.startswith('.'):
                d.remove(dir_)
        for f in files:
            if f[0] == '.':
                continue
            if f.endswith('.py') or f in EXTRA_FILES:
                yield os.path.join(r, f)


def test_pep8():
    assert check(_find_files_to_test()), "Found pep8 errors! (see logs below)"
